/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * example2.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */





import gov.aps.epics.jca.*;
import gov.aps.epics.jca.dbr.*;



public class example2 {

  static class ConnectionCallback implements ConnectionListener {
    public boolean connected=false;
    public void connectionChanged(ConnectionEvent ev) {
      connected= ev.isConnected();
    }
  }

  static class PutCallback implements PutListener {
    public boolean completed=false;
    public void putCompleted(PutEvent ev) {
      completed=true;
    }
  }

  static class GetCallback implements GetListener {
    public boolean completed=false;
    public DBR value=null;
    public void getCompleted(GetEvent ev) {
      value= ev.getDBR();
      completed=true;
    }
  }


  public static void main(String[] args) {

    if(args.length!=1) {
      System.out.println("usage: javaCA example2 'pvname'");
      System.exit(-1);
    }

    try {

      Context ctxt;
      Channel ch;
      DBR val;
      ConnectionCallback cnxCallback;
      PutCallback putCallback;
      GetCallback getCallback;

      
      //-------------------------------------------------------------

      System.out.println( "Creating context" );
      ctxt= Ca.createContext("MyContext", Ca.ENABLE_PREEMPTIVE_CALLBACK, Ca.THREAD_CTRL_EXTERNAL);


      //-------------------------------------------------------------

      cnxCallback= new ConnectionCallback();

      System.out.println( "\nConnecting channel: "+args[0] );
      ch= ctxt.createChannel(args[0], cnxCallback);
      ctxt.flushIO();

      System.out.print("waiting for request to complete.");
      int retry=0;
      while(!cnxCallback.connected && retry++<10) {
        System.out.print(".");
        try {
          Thread.sleep(1000);
        } catch(InterruptedException ie) {}
      }
      System.out.println((cnxCallback.connected?"OK":"FAILED"));
      if(!cnxCallback.connected) throw new Exception("Unable to connect channel: "+args[0]);

      ch.printInfo();


      //-------------------------------------------------------------

      putCallback= new PutCallback();

      System.out.println( "\nWriting string value to channel" );
      ch.put("5.7", putCallback);
      ctxt.flushIO();


      System.out.print("waiting for request to complete.");
      retry=0;
      while(!putCallback.completed && retry++<10) {
        System.out.print(".");
        try {
          Thread.sleep(1000);
        } catch(InterruptedException ie) {}
      }
      System.out.println((putCallback.completed?"OK":"FAILED"));
      if(!putCallback.completed) throw new Exception("Request failed");

      putCallback=null;

      //-------------------------------------------------------------

      getCallback= new GetCallback();

      System.out.println( "\nReading native type and length value from channel	" );
      ch.get(getCallback);
      ctxt.flushIO();
      
      System.out.print("waiting for request to complete.");
      retry=0;
      while(!getCallback.completed && retry++<10) {
        System.out.print(".");
        try {
          Thread.sleep(1000);
        } catch(InterruptedException ie) {}
      }
      System.out.println((getCallback.completed?"OK":"FAILED"));
      if(!getCallback.completed) throw new Exception("Request failed");

      val=getCallback.value;
      val.printInfo();

      getCallback=null;


      //-------------------------------------------------------------

      putCallback= new PutCallback();

      System.out.println( "\nWriting double value to channel" );
      ch.put(15.3, putCallback);
      ctxt.flushIO();

      System.out.print("waiting for request to complete.");
      retry=0;
      while(!putCallback.completed && retry++<10) {
        System.out.print(".");
        try {
          Thread.sleep(1000);
        } catch(InterruptedException ie) {}
      }
      System.out.println((putCallback.completed?"OK":"FAILED"));
      if(!putCallback.completed) throw new Exception("Request failed");

      putCallback=null;


      //-------------------------------------------------------------

      getCallback= new GetCallback();

      System.out.println( "\nReading a DBR_CTRL_DOUBLE type value from channel" );
      ch.get(Ca.DBR_CTRL_DOUBLE, 1, getCallback);
      ctxt.flushIO();

      System.out.print("waiting for request to complete.");
      retry=0;
      while(!getCallback.completed && retry++<10) {
        System.out.print(".");
        try {
          Thread.sleep(1000);
        } catch(InterruptedException ie) {}
      }
      System.out.println((getCallback.completed?"OK":"FAILED"));
      if(!getCallback.completed) throw new Exception("Request failed");

      val=getCallback.value;
      val.printInfo();

      getCallback=null;
      
      //-------------------------------------------------------------

      System.out.println( "\nDestroying channel" );
      ch.destroy();

      System.out.println( "\nDestroying context\n" );
      ctxt.destroy();


    }catch(Exception ex) {
      ex.printStackTrace();
      System.exit(-1);
    }

  }
}
