/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * ContextExceptionEvent.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */


package gov.aps.epics.jca;

import gov.aps.epics.jca.dbr.*;

/**
 * An event which indicates an asynchronous exception in a Context.
 *
 * Asynchronous context exceptions occur when a server notify the Context of a remote problem.
 *
 * @see Context
 */
public class ContextExceptionEvent extends CaEvent {
  Channel _channel;
  int _type;
  int _count;
  DBR _dbr;
  int _status;
  int _op;
  String _ctxtInfo;
  String _file;
  int _line;
  
  public ContextExceptionEvent(Context ctxt, Channel ch, int type, int count, DBR dbr, int status, int op, String ctxtInfo, String file, int line) {
    super(ctxt);
    _channel=ch;
    _type= type;
    _count=count;
    _dbr=dbr;
    _status=status;
    _op=op;
    _ctxtInfo=ctxtInfo;
    _file=file;
    _line=line;
  }

  /**
   * The Channel associated with the exception if any.
   * @return the Channel or null if none.
   */
  public Channel getChannel() { return _channel; }

  /**
   * Returns the type of the request when the failure occured.
   * @see CaConstants
   */
  public int getType()   { return _type; }
  /**
   * Returns the element count of the request when the failure occured.
   */
  public int getCount() { return _count; }
  /**
   * Returns the DBR object of the request when the failure occured.
   * Only valid for CA_OP_GET operation.
   * @return the DBR object or null if none.
   */
  public DBR getDBR()    { return _dbr; }

  /**
   * Returns the status of the operation when the failure occured.
   */
  public int getStatus() { return _status; }

  /**
   * Returns the OP code of the operation when the failure occured.
   * @see CaConstants
   */
  public int getOP() { return _op; }

  /**
   * Returns a String representing some information about the Context when the failure occured.
   */
  public String getContextInfo() { return _ctxtInfo; }

  /**
   * Returns the name of the file in which the failure occured if available.
   */
  public String getFile() { return _file; }
  
  /**
   * Returns the line number in the file where the failure occured if available.
   */
  public int getLine() { return _line; }

}

