/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * GetEvent.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */


package gov.aps.epics.jca;

import gov.aps.epics.jca.dbr.*;


/**
 * An event which indicates the completion of an asynchronous Get request.
 *
 * @see Channel
 */
public class GetEvent extends CaEvent  {
  protected DBR    _dbr;
  protected Object _usrArg;
  protected int    _status;


  public GetEvent(Channel channel, DBR dbr, Object usrArg, int status) {
    super(channel);
    _dbr=dbr;
    _usrArg=usrArg;
    _status=status;
  }

  /**
   * Returns the DBR object containing the requested value.
   */
  public DBR getDBR() {
    return _dbr;
  }

  public Object getUsrArg() {
    return _usrArg;
  }

  /**
   * Returns the status of the operation. One of ECA_XXX.
   * @see CaConstants
   */
  public int getStatus() {
    return _status;
  }

}

