/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * PutEvent.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */


package gov.aps.epics.jca;

import gov.aps.epics.jca.dbr.*;


/**
 * The listener interface for receiving PutEvents.
 *
 * @see Channel
 */
public class PutEvent extends CaEvent  {
  protected int _type;
  protected int _count;
  protected int _status;


  public PutEvent(Channel channel, int type, int count, int status) {
    super(channel);
    _type=type;
    _count=count;
    _status=status;
  }
  /**
   * Returns the type of the put request. One of DBR_XXX.
   * @see CaConstants
   */
  public int getType() {
    return _type;
  }

  /**
   * Returns the number of elements actualy written.
   */
  public int getCount() {
    return _count;
  }

  /**
   * Returns the status of the put request.
   */
  public int getStatus() {
    return _status;
  }

}

