/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBR_CTRL_Double.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */




package gov.aps.epics.jca.dbr;

import java.io.*;

public class DBR_CTRL_Double extends DBR_GR_Double implements CTRL {
  protected Double  _ucl=ZEROD;
  protected Double  _lcl=ZEROD;

  public DBR_CTRL_Double() {
    this(1);
  }

  public DBR_CTRL_Double(int count) {
    this(new double[count]);
  }

  public DBR_CTRL_Double(double[] value) {
    super(value);
    setType(DBR_CTRL_DOUBLE);
  }

  public Number getUpperCtrlLimit()                { return _ucl; }
  public void   setUpperCtrlLimit(Number limit)    { _ucl= new Double(limit.doubleValue()); }
  public Number getLowerCtrlLimit()                { return _lcl; }
  public void   setLowerCtrlLimit(Number limit)    { _lcl= new Double(limit.doubleValue()); }

  public void printInfo(PrintStream out) {
    super.printInfo(out);
    out.println("UCL      : "+ getUpperCtrlLimit());
    out.println("LCL      : "+ getLowerCtrlLimit());
  }

}


