/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * JNI.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */


package gov.aps.epics.jca.jni;

import gov.aps.epics.jca.*;
import gov.aps.epics.jca.dbr.*;


import java.security.*;


public class JNI {
  static {


    AccessController.doPrivileged(new PrivilegedAction() {
            public Object run() {
                // privileged code goes here, for example:
              System.loadLibrary("jca2");
                return null; // nothing to return
            }
        });

  }



  static native public int    _ca_getVersion();
  static native public int    _ca_getRevision();
  static native public int    _ca_getModification();
  static native public String _ca_getVersionString();
  static native public String _ca_getReleaseString();


  static native public int     _ctxt_contextCreate(int mode) throws CaException;
  static native public void    _ctxt_contextDestroy() throws CaException;
  static native public void    _ctxt_setMessageCallback(JNIContextMessageCallback callback) throws CaException;
  static native public void    _ctxt_setExceptionCallback(JNIContextExceptionCallback callback) throws CaException;
  static native public void    _ctxt_pendIO(double timeout) throws CaException;
  static native public boolean _ctxt_testIO() throws CaException;
  static native public void    _ctxt_pendEvent(double time) throws CaException;
  static native public void    _ctxt_poll() throws CaException;
  static native public void    _ctxt_flushIO() throws CaException;
  static native public void    _ctxt_attachThread(int ctxtID) throws CaException;


  static native public int     _ch_channelCreate(String name, JNIConnectionCallback callback) throws CaException;
  static native public void    _ch_channelDestroy(int channelID) throws CaException;
  static native public void    _ch_setConnectionCallback(int channelID, JNIConnectionCallback callback) throws CaException;
  static native public void    _ch_setAccessRightsCallback(int channelID, JNIAccessRightsCallback callback) throws CaException;
  static native public int     _ch_getFieldType(int channelID);
  static native public int     _ch_getElementCount(int channelID);
  static native public int     _ch_getState(int channelID);
  static native public String  _ch_getHostName(int channelID);
  static native public boolean _ch_getReadAccess(int channelID);
  static native public boolean _ch_getWriteAccess(int channelID);

  static native public void _ch_arrayPut(int type, int count, int channelID, int dbrID) throws CaException;
  static native public void _ch_arrayPutCallback(int type, int count, int channelID, int dbrID, JNIPutCallback callback) throws CaException;
  static native public void _ch_arrayGet(int type, int count, int channelID, int dbrID) throws CaException;
  static native public void _ch_arrayGetCallback(int type, int count, int channelID, JNIGetCallback callback) throws CaException;

  static native public int     _ch_addMonitor(int type, int count, int channelID, JNIMonitorCallback callback, int mask) throws CaException;
  static native public void    _ch_clearMonitor(int monitorID) throws CaException;



  static native public int       _dbr_create(int type, int count);
  static native public void      _dbr_destroy(int dbrid);
  static native public void      _dbr_setValue(int dbrid, int type, int count, Object value);
  static native public Object    _dbr_getValue(int dbrid, int type, int count, Object value);
  static native public short     _dbr_getStatus(int dbrid, int type);
  static native public short     _dbr_getSeverity(int dbrid, int type);
  static native public Number    _dbr_getUDL(int dbrid, int type);
  static native public Number    _dbr_getLDL(int dbrid, int type);
  static native public Number    _dbr_getUAL(int dbrid, int type);
  static native public Number    _dbr_getUWL(int dbrid, int type);
  static native public Number    _dbr_getLWL(int dbrid, int type);
  static native public Number    _dbr_getLAL(int dbrid, int type);
  static native public Number    _dbr_getUCL(int dbrid, int type);
  static native public Number    _dbr_getLCL(int dbrid, int type);
  static native public short     _dbr_getPrecision(int dbrid, int type);
  static native public TimeStamp _dbr_getTimeStamp(int dbrid, int type);
  static native public String[]  _dbr_getLabels(int dbrid, int type);
  static native public String    _dbr_getUnits(int dbrid, int type);
  static native public int       _dbr_getAckT(int dbrid, int type);
  static native public int       _dbr_getAckS(int dbrid, int type);

  static public void _dbr_update(DBR dbr, int dbrid) {
    int type= dbr.getType();
    int count= dbr.getCount();


    _dbr_getValue(dbrid,type,count,dbr.getValue());

    if (dbr instanceof STS) {
      ((STS)dbr).setStatus(_dbr_getStatus(dbrid,type));
      ((STS)dbr).setSeverity(_dbr_getSeverity(dbrid,type));
    }
    if (dbr instanceof TIME) {
      ((TIME)dbr).setTimeStamp(_dbr_getTimeStamp(dbrid,type));
    }
    if (dbr instanceof GR) {
      ((GR)dbr).setUnits(_dbr_getUnits(dbrid,type));
      ((GR)dbr).setUpperDispLimit(_dbr_getUDL(dbrid,type));
      ((GR)dbr).setLowerDispLimit(_dbr_getLDL(dbrid,type));
      ((GR)dbr).setUpperAlarmLimit(_dbr_getUAL(dbrid,type));
      ((GR)dbr).setUpperWarningLimit(_dbr_getUWL(dbrid,type));
      ((GR)dbr).setLowerWarningLimit(_dbr_getLWL(dbrid,type));
      ((GR)dbr).setLowerAlarmLimit(_dbr_getLAL(dbrid,type));
    }
    if (dbr instanceof CTRL) {
      ((CTRL)dbr).setUpperCtrlLimit(_dbr_getUCL(dbrid, type));
      ((CTRL)dbr).setLowerCtrlLimit(_dbr_getLCL(dbrid, type));
    }
    if (dbr instanceof PRECISION) {
      ((PRECISION)dbr).setPrecision(_dbr_getPrecision(dbrid,type));
    }
    if (dbr instanceof LABELS) {
      ((LABELS)dbr).setLabels(_dbr_getLabels(dbrid,type));
    }
    if (dbr instanceof ACK) {
      ((ACK)dbr).setAckT(_dbr_getAckT(dbrid,type));
      ((ACK)dbr).setAckS(_dbr_getAckS(dbrid,type));
    }
  }
}


