/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * JNIMonitor.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */

package gov.aps.epics.jca.jni;

import gov.aps.epics.jca.*;


public class JNIMonitor extends Monitor {
  protected JNIContext _jnicontext;
  protected int _type;
  protected int _count;
  protected JNIChannel _channel;
  protected MonitorListener _listener;
  protected int _mask;
  protected int _monitorID;

  public JNIMonitor(JNIContext context, int type, int count, JNIChannel ch, MonitorListener l, int mask) {
    _jnicontext= context;
    _type= type;
    _count=count;
    _channel= ch;
    _listener= l;
    _mask=mask;
  }

  public Context getContext() {
    return _jnicontext;
  }

  public Channel  getChannel() { 
    assertValidity();
    return _channel;
  }
  public JNIChannel  getJNIChannel() { 
    assertValidity();
    return _channel;
  }
  
  public int getType() { 
    assertValidity();
    return _type; 
  }
  public int getCount() { 
    assertValidity();
    return _count; 
  }
  public int getMask() { 
    assertValidity();
    return _mask;
  }
  public MonitorListener getMonitorListener() { 
    assertValidity();
    return _listener; 
  }
  public int getMonitorID() { 
    return _monitorID; 
  }

  protected void setMonitorID(int mID) {
    if(_monitorID!=0) throw new IllegalStateException("MonitorID has already been set");
    _monitorID= mID;
  }

  public void clear() throws CaException {
    assertValidity();
    _jnicontext.ch_clearMonitor(this);
  }

  protected void assertValidity() {
    if(_monitorID==0) throw new IllegalStateException("Invalid monitor");
  }
}


