/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * Monitor.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */

package jca;

import jca.event.*;

/*
 * This class allows users to keep track of their monitors.
 * 
 * @see jca.PV.addMonitor
 *
 * @deprecated
 */
public class Monitor extends Object {
  /**
   * The monitor is triggered when the PV value change.
   */
  public static final int VALUE             = 1;
  /**
   * The monitor is triggered when the PV log value change.
   */
  public static final int LOG               = 2;
  /**
   * The monitor is triggered when the PV alarm state change.
   */
  public static final int ALARM             = 4;

  protected gov.aps.epics.jca.Monitor _monitor;

  protected Monitor(gov.aps.epics.jca.Monitor m) {
    _monitor= m;
  }

  /**
   * Clear the monitor.
   *
   * @exception jca.BadMonitorException thrown if the monitor has already been cleared.
   */
  public void clear() throws BadMonitorException {
    if(_monitor==null) throw new BadMonitorException();
    try {
      _monitor.clear();
    } catch(gov.aps.epics.jca.CaException cae) {
    } finally {
      _monitor=null;
    }
  }

  /**
   * Return the monitor ID. All Monitor have their own ID.
   */
  public int id() {
    return (_monitor==null?0:1);
  }
}
