/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBDouble.java,v 1.1.1.1 2003/09/11 14:42:50 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */

package jca.dbr;
import java.lang.*;

/**
 * This class represents a Channel Access database double value.
 *
 * @see jca.dbr.DBData
 */
public class DBDouble extends DBData {
  /**
   * Construct a new DBDouble object.
   *
   * @param val the DBDouble value.
   */
  public DBDouble(double val) {
    m_value= val;
  }
  
  /**
   * Return the value as a byte.
   */
  public byte byteValue() {
    return (byte)m_value;
  }
  
  /**
   * Return the value as a short.
   */
  public short shortValue() {
    return (short)m_value;
  }
  
  /**
   * Return the value as an int.
   */
  public int intValue() {
    return (int)m_value;
  }
  
  /**
   * Return the value as a long.
   */
  public long longValue() {
    return (long)m_value;
  }
  
  /**
   * Return the value as a float.
   */
  public float floatValue() {
    return (float)m_value;
  }
  
  /**
   * Return the value as a double.
   */
  public double doubleValue() {
    return (double)m_value;
  }
  
  /**
   * Return the value as a String.
   * The convertion is made by calling String.valueOf().
   */
  public String stringValue() {
    return String.valueOf(m_value);
  }

  private double m_value;
}
