/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBR_DBDouble.java,v 1.1.1.1 2003/09/11 14:42:50 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */

package jca.dbr;
import java.lang.*;

/**
 * This class represents the Channel Access DBR_DOUBLE type.
 *
 */
public class DBR_DBDouble implements DBR {
  protected int      m_count= 0;
  protected double[] m_value= null;

  public DBR_DBDouble() {
    this(new double[1]);
  }
  
  public DBR_DBDouble(int count) {
    this(new double[count]);
  }

  public DBR_DBDouble(DBData val) {
    m_count= 1;
    m_value= new double[1];
    m_value[0]= val.doubleValue();
  }

  public DBR_DBDouble(double[] val) {
    m_count= val.length;
    m_value= val;
  }

  public int type() {
    return DBR.DOUBLE;
  }
  
  public int count() {
    return m_count;
  }

  public DBData dataAt(int at) {
    return new DBDouble(m_value[at]);
  }

  public double valueAt(int at) {
    return m_value[at];
  }

  public double[] value() {
    return m_value;
  }
  public void update(gov.aps.epics.jca.dbr.DBR source) {
    System.arraycopy(source.getValue(), 0, m_value, 0, m_count);
  }

}
