/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBR_GR_DBDouble.java,v 1.1.1.1 2003/09/11 14:42:50 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */

package jca.dbr;
import java.lang.*;

/**
 * This class represents the Channel Access DBR_GR_DOUBLE type.
 *
 */
public class DBR_GR_DBDouble extends DBR_STS_DBDouble implements DBR_GR {
  protected short  m_precision;
  protected String m_units;
  protected double   m_upper_disp_limit;
  protected double   m_lower_disp_limit;
  protected double   m_upper_alarm_limit;
  protected double   m_upper_warning_limit;
  protected double   m_lower_warning_limit;
  protected double   m_lower_alarm_limit;

  public DBR_GR_DBDouble() {
    super(1);
  }
  
  public DBR_GR_DBDouble(int count) {
    super(count);
  }

  public int type() {
    return DBR.GR_DOUBLE;
  }

  public short precision() {
    return m_precision;
  }

  public String units() {
    return m_units;
  }

  public DBData upperDispLimit() {
    return new DBDouble(m_upper_disp_limit);
  }

  public DBData lowerDispLimit() {
    return new DBDouble(m_lower_disp_limit);
  }

  public DBData upperAlarmLimit() {
    return new DBDouble(m_upper_alarm_limit);
  }

  public DBData upperWarningLimit() {
    return new DBDouble(m_upper_warning_limit);
  }

  public DBData lowerWarningLimit() {
    return new DBDouble(m_lower_warning_limit);
  }

  public DBData lowerAlarmLimit() {
    return new DBDouble(m_lower_alarm_limit);
  }
  
/*
  protected void setInfo(short status, short severity,
                         short precision,
                         String units,
                         double upper_disp_limit,
                         double lower_disp_limit,
                         double upper_alarm_limit,
                         double upper_warning_limit,
                         double lower_warning_limit,
                         double lower_alarm_limit) {
    super.setInfo(status,severity);
    m_precision= precision;
    m_units= units;
    m_upper_disp_limit   = upper_disp_limit;
    m_lower_disp_limit   = lower_disp_limit;
    m_upper_alarm_limit  = upper_alarm_limit;
    m_upper_warning_limit= upper_warning_limit;
    m_lower_warning_limit= lower_warning_limit;
    m_lower_alarm_limit  = lower_alarm_limit;
  };                      
*/
  public void update(gov.aps.epics.jca.dbr.DBR source) {
    super.update(source);

    gov.aps.epics.jca.dbr.GR gr= (gov.aps.epics.jca.dbr.GR)source;

    m_units              = gr.getUnits();
    m_upper_disp_limit   = gr.getUpperDispLimit().doubleValue();
    m_lower_disp_limit   = gr.getLowerDispLimit().doubleValue();
    m_upper_alarm_limit  = gr.getUpperAlarmLimit().doubleValue();
    m_upper_warning_limit= gr.getUpperWarningLimit().doubleValue();
    m_lower_warning_limit= gr.getLowerWarningLimit().doubleValue();
    m_lower_alarm_limit  = gr.getLowerAlarmLimit().doubleValue();

    gov.aps.epics.jca.dbr.PRECISION prec= (gov.aps.epics.jca.dbr.PRECISION) source;
    m_precision= prec.getPrecision();

  }

}
