/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBR_GR_DBShort.java,v 1.1.1.1 2003/09/11 14:42:50 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */

package jca.dbr;
import java.lang.*;

/**
 * This class represents the Channel Access DBR_GR_SHORT type.
 *
 */
public class DBR_GR_DBShort extends DBR_STS_DBShort implements DBR_GR {
  protected String m_units;
  protected short   m_upper_disp_limit;
  protected short   m_lower_disp_limit;
  protected short   m_upper_alarm_limit;
  protected short   m_upper_warning_limit;
  protected short   m_lower_warning_limit;
  protected short   m_lower_alarm_limit;

  public DBR_GR_DBShort() {
    super(1);
  }
  
  public DBR_GR_DBShort(int count) {
    super(count);
  }

  public int type() {
    return DBR.GR_SHORT;
  }

  public String units() {
    return m_units;
  }

  public DBData upperDispLimit() {
    return new DBShort(m_upper_disp_limit);
  }

  public DBData lowerDispLimit() {
    return new DBShort(m_lower_disp_limit);
  }

  public DBData upperAlarmLimit() {
    return new DBShort(m_upper_alarm_limit);
  }

  public DBData upperWarningLimit() {
    return new DBShort(m_upper_warning_limit);
  }

  public DBData lowerWarningLimit() {
    return new DBShort(m_lower_warning_limit);
  }

  public DBData lowerAlarmLimit() {
    return new DBShort(m_lower_alarm_limit);
  }
  
/*
  protected void setInfo(short status, short severity,
                      String units,
                      short upper_disp_limit,
                      short lower_disp_limit,
                      short upper_alarm_limit,
                      short upper_warning_limit,
                      short lower_warning_limit,
                      short lower_alarm_limit) {
    super.setInfo(status,severity);
    m_units= units;
    m_upper_disp_limit   = upper_disp_limit;
    m_lower_disp_limit   = lower_disp_limit;
    m_upper_alarm_limit  = upper_alarm_limit;
    m_upper_warning_limit= upper_warning_limit;
    m_lower_warning_limit= lower_warning_limit;
    m_lower_alarm_limit  = lower_alarm_limit;
  };                      
*/

  public void update(gov.aps.epics.jca.dbr.DBR source) {
    super.update(source);

    gov.aps.epics.jca.dbr.GR gr= (gov.aps.epics.jca.dbr.GR)source;

    m_units              = gr.getUnits();
    m_upper_disp_limit   = gr.getUpperDispLimit().shortValue();
    m_lower_disp_limit   = gr.getLowerDispLimit().shortValue();
    m_upper_alarm_limit  = gr.getUpperAlarmLimit().shortValue();
    m_upper_warning_limit= gr.getUpperWarningLimit().shortValue();
    m_lower_warning_limit= gr.getLowerWarningLimit().shortValue();
    m_lower_alarm_limit  = gr.getLowerAlarmLimit().shortValue();

  }

}
